@@ -1,21 +1,27 @@
 import numpy as np
 import scipy as sp
+import pandas as pd
 
 def fft(data):
 
     """
-    Compute the 1-D discrete Fourier Transform. 
+    Compute the 1-D discrete Fourier Transformation. 
     
     Args:
-        data (dataframe): The dataframe with two columns, time and value
+        data (dataframe or list): The dataframe or list with two columns, first: time, second: value
     Returns:
         frq (array): x-axis of the descrete frequency spectrum 
         amp (array): y-axis of the descrete frequency spectrum 
     """
 
-    # acess data frame
-    x = data.iloc[:, 0]
-    y = data.iloc[:, 1]
+    # acess data frame or list. Raise error if neither is given.
+    if isinstance(data,pd.DataFrame):
+        x = data.iloc[:, 0]
+        y = data.iloc[:, 1]
+    elif isinstance(data, list):
+        x = data[0]
+        y = data[1]
+    else: raise Exception('Possible input: pd.DataFrame or list')
     
     # sampling interval
     si = np.median(np.diff(x))
